xerrors

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package xerrors provides error values that can carry a captured call stack.

Formatting:

  • %v prints the error message (like the standard library)
  • %+v prints the error message followed by a stack trace

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(msg string) error

func Stacktrace

func Stacktrace(err error) stacktraceStringer

func StacktraceReleaser

func StacktraceReleaser(err error) interface{ ReleaseStacktrace() }

func WithStack

func WithStack(err error) error

Types

type StacktraceLease

type StacktraceLease = tracer

Jump to