Documentation
¶
Overview ¶
Package xerrors provides error values that can carry a captured call stack.
Formatting:
- %v prints the error message (like the standard library)
- %+v prints the error message followed by a stack trace
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Stacktrace ¶
func Stacktrace(err error) stacktraceStringer
func StacktraceReleaser ¶
func StacktraceReleaser(err error) interface{ ReleaseStacktrace() }
Types ¶
type StacktraceLease ¶
type StacktraceLease = tracer
Click to show internal directories.
Click to hide internal directories.